==> savane-1.0.4.tar.gz: savane/frontend/php/account/lostlogin.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: lostlogin.php,v 1.13 2004/01/31 00:56:17 yeupou Exp $
//
//
// Copyright 1999-2000 (c) The SourceForge Crew
//
//
//  Copyright (C) 2000-2003 Free Software Foundation
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//
//
//

require "../include/pre.php";    
require  $GLOBALS['sys_urlroot']."/include/account.php";

// ###### function register_valid()
// ###### checks for valid register from form post

$res_lostuser = db_query("SELECT * FROM user WHERE confirm_hash='$confirm_hash'");
if (db_numrows($res_lostuser) > 1) {
	exit_error(_("Error"),_("This confirm hash exists more than once."));
}
if (db_numrows($res_lostuser) < 1) {
	exit_error(_("Error"),_("Invalid confirmation hash."));
}
$row_lostuser = db_fetch_array($res_lostuser);

if ($Update && $form_pw && !strcmp($form_pw,$form_pw2)) {
	db_query("UPDATE user SET "
		. "user_pw='" . md5($form_pw) . "',"
		. "confirm_hash='',"
		. "unix_pw='" . account_genunixpw($form_pw) . "' WHERE "
		. "confirm_hash='$confirm_hash'");


	session_redirect($GLOBALS['sys_home']);
}

$HTML->header(array('title'=>_("Lost Password Login")));

print '<h3>'._("Lost Password Login").'</h3>';
print '<p>'._("Welcome").', '.$row_lostuser['user_name'].'.';
print ' '._("You may now change your password").'.</p>';

print '<form action="lostlogin.php">';
print '<div class="inputfield"><h5>'._("New Password:").'</h5>';
print '<input type="password" name="form_pw"></div>';

print '<div class="inputfield"><h5>'._("New Password (repeat):").'</h5>';
print '<input type="password" name="form_pw2"></div>';

print '<input type="hidden" name="confirm_hash" value="'.$confirm_hash.'">';
print '<p><input type="submit" name="Update" value="'._("Update").'"></p>';
print '</form>';

$HTML->footer(array());

?>

==> savane-1.0.5a.tar.gz: savane/frontend/php/account/lostlogin.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: lostlogin.php,v 1.15 2004/11/22 08:25:48 yeupou Exp $
//
//
// Copyright 1999-2000 (c) The SourceForge Crew
//
//
//  Copyright (C) 2000-2003 Free Software Foundation
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//
//
//

require "../include/pre.php";    
require  $GLOBALS['sys_urlroot']."/include/account.php";

// ###### function register_valid()
// ###### checks for valid register from form post

$res_lostuser = db_query("SELECT * FROM user WHERE confirm_hash='$confirm_hash'");
if (db_numrows($res_lostuser) > 1) {
	exit_error(_("Error"),_("This confirm hash exists more than once."));
}
if (db_numrows($res_lostuser) < 1) {
	exit_error(_("Error"),_("Invalid confirmation hash."));
}
$row_lostuser = db_fetch_array($res_lostuser);

if ($update && form_check($form_id) && $form_pw && !strcmp($form_pw,$form_pw2)) {
  db_query("UPDATE user SET "
	   . "user_pw='" . md5($form_pw) . "',"
	   . "confirm_hash='' WHERE "
	   . "confirm_hash='$confirm_hash'");
  
  form_clean($form_id);
  session_redirect($GLOBALS['sys_home']);
}

$HTML->header(array('title'=>_("Lost Password Login")));

print '<h3>'._("Lost Password Login").'</h3>';
print '<p>'._("Welcome").', '.$row_lostuser['user_name'].'.';
print ' '._("You may now change your password").'.</p>';

print form_header($PHP_SELF);

print '<form action="lostlogin.php">';
print '<div class="inputfield"><h5>'._("New Password:").'</h5>';
print form_input("password", "form_pw").'</div>';

print '<div class="inputfield"><h5>'._("New Password (repeat):").'</h5>';
print form_input("password", "form_pw2").'</div>';

print form_input("hidden", "confirm_hash", $confirm_hash);
print form_footer();

$HTML->footer(array());

?>
